@@ -2,7 +2,7 @@ package MooseX::DeclareX::Plugin::public;
 
 BEGIN {
 	$MooseX::DeclareX::Plugin::public::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::DeclareX::Plugin::public::VERSION   = '0.004';
+	$MooseX::DeclareX::Plugin::public::VERSION   = '0.005';
 }
 
 use Moose;
@@ -22,11 +22,21 @@ sub plugin_setup
 		if $kw->can('add_namespace_customizations');
 }
 
+sub HAS
+{
+	my $attrs = shift;
+	Moose->throw_error('Usage: public has \'name\' => ( key => value, ... )')
+		if @_ % 2 == 1;
+	$attrs = [$attrs] unless ref $attrs eq 'ARRAY';
+	my %options = ( definition_context => Moose::Util::_caller_info(), @_ );
+	caller->meta->add_attribute($_, %options) for @$attrs;
+}
+
 package MooseX::DeclareX::Plugin::public::Role;
 
 BEGIN {
 	$MooseX::DeclareX::Plugin::public::Role::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::DeclareX::Plugin::public::Role::VERSION   = '0.004';
+	$MooseX::DeclareX::Plugin::public::Role::VERSION   = '0.005';
 }
 
 use Moose::Role;
@@ -44,12 +54,14 @@ package MooseX::DeclareX::Plugin::public::Parser;
 
 BEGIN {
 	$MooseX::DeclareX::Plugin::public::Parser::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::DeclareX::Plugin::public::Parser::VERSION   = '0.004';
+	$MooseX::DeclareX::Plugin::public::Parser::VERSION   = '0.005';
 }
 
 use Moose;
 extends 'MooseX::DeclareX::MethodPrefix';
 
+sub handle_has { 'MooseX::DeclareX::Plugin::public::HAS' };
+
 override prefix_keyword => sub { 'public' };
 override install_method => sub {
 	my ($self, $method) = @_;
